tietools.is_component_with_tie_spanner_attached
===============================================

.. autofunction:: abjad.tools.tietools.is_component_with_tie_spanner_attached.is_component_with_tie_spanner_attached
